@@ -1,6 +1,9 @@
 
+from functools import partial
+
 from django.db import models
 from django.db.models import F
+from django.db.models.signals import post_save
 from django.utils.translation import ugettext_lazy as _
 
 from solo.models import SingletonModel
@@ -53,44 +56,14 @@ class ExchangeRates(SingletonModel):
         verbose_name_plural = _('Exchange rates')
 
 
-class BasePrice(models.Model):
-
-    price = NotImplemented
-
-    @property
-    def currency(self):
-        return getattr(self, 'annotated_currency', CURRENCY_UAH)
-
-    @property
-    def printable_price(self):
-        return format_printable_price(self.price, self.currency)
-
-    @property
-    def schema_price(self):
-        return str(self.price).replace(',', '.')
-
-    @property
-    def schema_currency(self):
-        return CURRENCY_NAMES[self.currency].upper()
-
-    @property
-    def price_values(self):
-        raise NotImplementedError
-
-    @classmethod
-    def format_printable_price(cls, *args, **kwargs):
-        return format_printable_price(*args, **kwargs)
-
-    class Meta:
-        abstract = True
-
-
-class MultiCurrencyPrice(BasePrice):
-
-    price_wholesale = models.FloatField(_('Wholesale price'))
+class MultiCurrencyPrice(models.Model):
 
     price_retail = models.FloatField(_('Retail price'))
 
+    price_wholesale = models.FloatField(
+        _('Wholesale price'),
+        default=0)
+
     price_usd = models.FloatField(default=0)
 
     price_eur = models.FloatField(default=0)
@@ -110,6 +83,26 @@ class MultiCurrencyPrice(BasePrice):
     def printable_price(self):
         return format_printable_price(self.price, self.currency)
 
+    @property
+    def currency(self):
+        return getattr(self, 'annotated_currency', CURRENCY_UAH)
+
+    @property
+    def printable_price(self):
+        return format_printable_price(self.price, self.currency)
+
+    @property
+    def schema_price(self):
+        return str(self.price).replace(',', '.')
+
+    @property
+    def schema_currency(self):
+        return CURRENCY_NAMES[self.currency].upper()
+
+    @classmethod
+    def format_printable_price(cls, *args, **kwargs):
+        return format_printable_price(*args, **kwargs)
+
     @property
     def price_values(self):
 
@@ -126,20 +119,3 @@ class MultiCurrencyPrice(BasePrice):
 
     class Meta:
         abstract = True
-
-
-class SingleCurrencyPrice(BasePrice):
-
-    price = models.FloatField(_('Price'))
-
-    @property
-    def printable_price(self):
-        return format_printable_price(self.price, self.currency)
-
-    @property
-    def price_values(self):
-        fields = ['price']
-        return {field: getattr(self, field) for field in fields}
-
-    class Meta:
-        abstract = True
