@@ -1,11 +1,14 @@
 
 class ExchangeSettings(object):
 
-    PRICE_MODEL = 'exchange.models.MultiCurrencyPrice'
-
     @property
     def INSTALLED_APPS(self):
-        return super().INSTALLED_APPS + ['exchange']
+        apps = super().INSTALLED_APPS + ['exchange']
+
+        if 'solo' not in apps:
+            apps.append('solo')
+
+        return apps
 
     @property
     def CONTEXT_PROCESSORS(self):
