@@ -67,8 +67,3 @@ def get_price_factory(rates, src, dst):
         return lambda p: p / rates.usd_eur
 
     raise ValueError('Unknown currencies')
-
-
-def get_price_class():
-    path = settings.PRICE_MODEL.split('.')
-    return getattr(import_module('.'.join(path[:-1])), path[-1])
